@@ -13,48 +13,38 @@
  * to license@zend.com so we can send you a copy immediately.
  *
  * @category   Zend
- * @package    UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @package    Zend
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestHelper.php 9225 2008-04-14 18:44:43Z darby $
+ * @version    $Id$
  */
 
-/*
- * Start output buffering
- */
-ob_start();
-
-/*
+/**
  * Include PHPUnit dependencies
  */
-require_once 'PHPUnit/Framework.php';
-require_once 'PHPUnit/Framework/IncompleteTestError.php';
-require_once 'PHPUnit/Framework/TestCase.php';
-require_once 'PHPUnit/Framework/TestSuite.php';
 require_once 'PHPUnit/Runner/Version.php';
-require_once 'PHPUnit/TextUI/TestRunner.php';
-require_once 'PHPUnit/Util/Filter.php';
+
+$phpunitVersion = PHPUnit_Runner_Version::id();
+if ($phpunitVersion == '@package_version@' || version_compare($phpunitVersion, '3.5.5', '>=')) {
+    require_once 'PHPUnit/Autoload.php'; // >= PHPUnit 3.5.5
+} else {
+    require_once 'PHPUnit/Framework.php'; // < PHPUnit 3.5.5
+}
 
 /*
  * Set error reporting to the level to which Zend Framework code must comply.
  */
-error_reporting( E_ALL | E_STRICT );
+error_reporting(E_ALL | E_STRICT);
 
 /*
  * Determine the root, library, and tests directories of the framework
  * distribution.
  */
-$zfRoot        = dirname(__FILE__) . '/..';
+$zfRoot        = realpath(dirname(dirname(__FILE__)));
 $zfCoreLibrary = "$zfRoot/library";
 $zfCoreTests   = "$zfRoot/tests";
 
-/*
- * Omit from code coverage reports the contents of the tests directory
- */
-foreach (array('php', 'phtml', 'csv') as $suffix) {
-    PHPUnit_Util_Filter::addDirectoryToFilter($zfCoreTests, ".$suffix");
-}
-
 /*
  * Prepend the Zend Framework library/ and tests/ directories to the
  * include_path. This allows the tests to run out of the box and helps prevent
@@ -78,18 +68,18 @@ if (is_readable($zfCoreTests . DIRECTORY_SEPARATOR . 'TestConfiguration.php')) {
     require_once $zfCoreTests . DIRECTORY_SEPARATOR . 'TestConfiguration.php.dist';
 }
 
-/*
- * Add Zend Framework library/ directory to the PHPUnit code coverage
- * whitelist. This has the effect that only production code source files appear
- * in the code coverage report and that all production code source files, even
- * those that are not covered by a test yet, are processed.
+/**
+ * Start output buffering, if enabled
  */
-if (defined('TESTS_GENERATE_REPORT') && TESTS_GENERATE_REPORT === true &&
-    version_compare(PHPUnit_Runner_Version::id(), '3.1.6', '>=')) {
-    PHPUnit_Util_Filter::addDirectoryToWhitelist($zfCoreLibrary);
+if (defined('TESTS_ZEND_OB_ENABLED') && constant('TESTS_ZEND_OB_ENABLED')) {
+    ob_start();
 }
 
 /*
  * Unset global variables that are no longer needed.
  */
 unset($zfRoot, $zfCoreLibrary, $zfCoreTests, $path);
+
+// Suppress DateTime warnings
+date_default_timezone_set(@date_default_timezone_get());
+
