@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,24 +15,23 @@
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: CountTest.php 6453 2007-09-21 16:12:29Z darby $
+ * @version    $Id$
  */
 
-
 /**
  * @see Zend_Feed
  */
 require_once 'Zend/Feed.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Feed
  */
 class Zend_Feed_CountTest extends PHPUnit_Framework_TestCase
 {
@@ -44,4 +42,13 @@ class Zend_Feed_CountTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($f->count(), 2, 'Feed count should be 2');
     }
 
+    /**
+    * ZF-3848
+    */
+    public function testCountableInterface()
+    {
+        $f = Zend_Feed::importFile(dirname(__FILE__) . '/_files/TestAtomFeed.xml');
+        $this->assertEquals(count($f), 2, 'Feed count should be 2');
+    }
+
 }
