@@ -87,6 +87,28 @@ class Zend_LocaleTest extends PHPUnit_Framework_TestCase
         setlocale(LC_ALL, $this->_locale);
     }
 
+    /**
+     * Test that locale names that have been dropped from CLDR continue to
+     * work.
+     */
+    public function testAliases()
+    {
+        $locale = new Zend_Locale('zh_CN');
+        $this->assertEquals(true, $locale->isLocale('zh_CN'));
+        $this->assertEquals('zh', $locale->getLanguage());
+        $this->assertEquals('CN', $locale->getRegion());
+        $this->assertEquals(true, Zend_Locale::isAlias($locale));
+        $this->assertEquals(true, Zend_Locale::isAlias('zh_CN'));
+        $this->assertEquals('zh_Hans_CN', Zend_Locale::getAlias('zh_CN'));
+
+        $locale = new Zend_Locale('zh_Hans_CN');
+        $this->assertEquals(true, $locale->isLocale('zh_Hans_CN'));
+        $this->assertEquals('zh', $locale->getLanguage());
+        $this->assertEquals('CN', $locale->getRegion());
+        $this->assertEquals(false, Zend_Locale::isAlias('zh_Hans_CN'));
+        $this->assertEquals('zh_Hans_CN', Zend_Locale::getAlias('zh_Hans_CN'));
+    }
+
     /**
      * test for object creation
      * expected object instance
@@ -869,6 +891,53 @@ class Zend_LocaleTest extends PHPUnit_Framework_TestCase
 		$this->assertEquals('2', Zend_Locale::getTranslation('DEFAULT', 'CurrencyFraction'));
     }
 
+    public function testEachDataFileShouldPresentAsLocaleData()
+    {
+        if (version_compare(PHP_VERSION, '5.3.2', 'lt')) {
+            $this->markTestSkipped('ReflectionMethod::setAccessible can only be run under 5.3.2 or later');
+        }
+
+        $dir = new DirectoryIterator(
+            dirname(__FILE__) . '/../../library/Zend/Locale/Data'
+        );
+        $skip = array(
+            'characters.xml',
+            'coverageLevels.xml',
+            'dayPeriods.xml',
+            'genderList.xml',
+            'languageInfo.xml',
+            'likelySubtags.xml',
+            'metaZones.xml',
+            'numberingSystems.xml',
+            'postalCodeData.xml',
+            'supplementalData.xml',
+            'supplementalMetadata.xml',
+            'telephoneCodeData.xml',
+            'Translation.php',
+            'windowsZones.xml',
+        );
+
+        $files = array('root');
+        /** @var SplFileInfo $fileinfo */
+        foreach ($dir as $fileinfo) {
+            if (!$fileinfo->isDot()
+                && !in_array($fileinfo->getBasename(), $skip)
+            ) {
+                $files[] = $fileinfo->getBasename('.xml');
+            }
+        }
+
+        $class    = new ReflectionClass('Zend_Locale');
+        $property = $class->getProperty('_localeData');
+        $property->setAccessible(true);
+
+        $locale     = new Zend_Locale();
+        $localeData = $property->getValue($locale);
+        $localeData = array_keys($localeData);
+
+        $this->assertEquals(array(), array_diff($files, $localeData));
+    }
+
     /**
      * Ignores a raised PHP error when in effect, but throws a flag to indicate an error occurred
      *
