@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: HostnameTest.php 25061 2012-11-02 21:24:09Z rob $
+ * @version    $Id$
  */
 
 /**
@@ -30,7 +30,7 @@ require_once 'Zend/Validate/Hostname.php';
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Validate
  */
@@ -228,7 +228,7 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
 
         // Check TLD matching
         $valuesExpected = array(
-            array(true, array('domain.co.uk', 'domain.uk.com', 'domain.tl', 'domain.zw')),
+            array(true, array('domain.co.uk', 'domain.uk.com', 'domain.tl', 'domain.zw', 'domain.menu')),
             array(false, array('domain.xx', 'domain.zz', 'domain.madeup'))
             );
         foreach ($valuesExpected as $element) {
@@ -423,7 +423,7 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
             }
         }
     }
-    
+
     /**
      * @group ZF-11334
      * @see http://www.ietf.org/rfc/rfc2732.txt
@@ -431,7 +431,7 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
     public function testSupportsIpv6AddressesWhichContainHexDigitF()
     {
         $validator = new Zend_Validate_Hostname(Zend_Validate_Hostname::ALLOW_ALL);
-        
+
         $this->assertTrue($validator->isValid('FEDC:BA98:7654:3210:FEDC:BA98:7654:3210'));
         $this->assertTrue($validator->isValid('1080:0:0:0:8:800:200C:417A'));
         $this->assertTrue($validator->isValid('3ffe:2a00:100:7031::1'));
@@ -440,14 +440,14 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($validator->isValid('::FFFF:129.144.52.38'));
         $this->assertTrue($validator->isValid('2010:836B:4179::836B:4179'));
     }
-    
+
     /**
      * @group ZF-11796
      */
     public function testIDNSI()
     {
         $validator = new Zend_Validate_Hostname(Zend_Validate_Hostname::ALLOW_ALL);
-        
+
         $this->assertTrue($validator->isValid('Test123.si'));
         $this->assertTrue($validator->isValid('țest123.si'));
         $this->assertTrue($validator->isValid('tĕst123.si'));
@@ -462,4 +462,40 @@ class Zend_Validate_HostnameTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($this->_validator->isValid('testæøå.dk'));
     }
 
+    /**
+     * test for IDN CA
+     */
+    public function testIDNCA()
+    {
+        $validator = new Zend_Validate_Hostname(Zend_Validate_Hostname::ALLOW_ALL);
+
+        $this->assertTrue($validator->isValid('Test123.ca'));
+        $this->assertTrue($validator->isValid('tàr.ca'));
+        $this->assertFalse($validator->isValid('țest123.ca'));
+        $this->assertFalse($validator->isValid('tĕst123.ca'));
+        $this->assertFalse($validator->isValid('رات.ca'));
+    }
+
+    /**
+     * @group ZF-12413
+     */
+    public function testIDNUA()
+    {
+        $validator = new Zend_Validate_Hostname(Zend_Validate_Hostname::ALLOW_ALL);
+
+        $this->assertTrue($validator->isValid('самобраноч.com.ua'));
+        $this->assertTrue($validator->isValid('hostmaster.ua'));
+    }
+
+    /**
+     * Test for IDN serbia .rs
+     *
+     * @group GH-115
+     */
+    public function testIDNRS()
+    {
+        $validator = new Zend_Validate_Hostname(Zend_Validate_Hostname::ALLOW_ALL);
+
+        $this->assertTrue($validator->isValid('test.rs'));
+    }
 }
