@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,16 +15,15 @@
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MessageTest.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id$
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
+// Call Zend_Validate_MessageTest::main() if this source file is executed directly.
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_Validate_MessageTest::main');
+}
 
 /**
  * @see Zend_Validate_StringLength
@@ -37,8 +35,9 @@ require_once 'Zend/Validate/StringLength.php';
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Validate
  */
 class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
 {
@@ -49,6 +48,12 @@ class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
      */
     protected $_validator;
 
+    public static function main()
+    {
+        $suite  = new PHPUnit_Framework_TestSuite(__CLASS__);
+        $result = PHPUnit_TextUI_TestRunner::run($suite);
+    }
+
     /**
      * Creates a new Zend_Validate_StringLength object for each test method
      *
@@ -70,7 +75,7 @@ class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
         $inputInvalid = 'abcdefghij';
         $this->assertFalse($this->_validator->isValid($inputInvalid));
         $messages = $this->_validator->getMessages();
-        $this->assertEquals("'$inputInvalid' is greater than 8 characters long", current($messages));
+        $this->assertEquals("'$inputInvalid' is more than 8 characters long", current($messages));
 
         $this->_validator->setMessage(
             'Your value is too long',
@@ -93,7 +98,7 @@ class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
     public function testSetMessageDefaultKey()
     {
         $this->_validator->setMessage(
-            'Your value is too short'
+            'Your value is too short', Zend_Validate_StringLength::TOO_SHORT
         );
 
         $this->assertFalse($this->_validator->isValid('abc'));
@@ -179,7 +184,7 @@ class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
             );
             $this->fail('Expected to catch Zend_Validate_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Validate_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Validate_Exception,
                 'Expected exception of type Zend_Validate_Exception, got ' . get_class($e));
             $this->assertEquals("No message template exists for key '$keyInvalid'", $e->getMessage());
         }
@@ -257,7 +262,7 @@ class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
             $property = $this->_validator->unknownProperty;
             $this->fail('Expected to catch Zend_Validate_Exception');
         } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Validate_Exception', $e,
+            $this->assertTrue($e instanceof Zend_Validate_Exception,
                 'Expected exception of type Zend_Validate_Exception, got ' . get_class($e));
             $this->assertEquals("No property exists by the name 'unknownProperty'", $e->getMessage());
         }
@@ -275,7 +280,7 @@ class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
         $this->assertFalse($this->_validator->isValid($inputInvalid));
 
         $messages = $this->_validator->getMessages();
-        $this->assertEquals("'$inputInvalid' is greater than 8 characters long", current($messages));
+        $this->assertEquals("'$inputInvalid' is more than 8 characters long", current($messages));
 
         $errors = $this->_validator->getErrors();
         $this->assertEquals(Zend_Validate_StringLength::TOO_LONG, current($errors));
@@ -290,13 +295,13 @@ class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
     {
         $vars = $this->_validator->getMessageVariables();
 
-        $this->assertType('array', $vars);
+        $this->assertTrue(is_array($vars));
         $this->assertEquals(array('min', 'max'), $vars);
         $message = 'variables: %notvar% ';
         foreach ($vars as $var) {
             $message .= "%$var% ";
         }
-        $this->_validator->setMessage($message);
+        $this->_validator->setMessage($message, Zend_Validate_StringLength::TOO_SHORT);
 
         $this->assertFalse($this->_validator->isValid('abc'));
         $messages = $this->_validator->getMessages();
@@ -304,3 +309,8 @@ class Zend_Validate_MessageTest extends PHPUnit_Framework_TestCase
     }
 
 }
+
+// Call Zend_Validate_MessageTest::main() if this source file is executed directly.
+if (PHPUnit_MAIN_METHOD == 'Zend_Validate_MessageTest::main') {
+    Zend_Validate_MessageTest::main();
+}
